==> wm-react-native-components-0.0.57.tgz: package/refreshlistview/LoadingMore.js <==

import React,{Component, PureComponent}  from 'react';
import {
    StyleSheet,
    View,
    Text,
    TouchableWithoutFeedback,
    Dimensions,
    Image,
    Animated,
} from 'react-native';

import WMImage from '../WMImage';
import WMView from '../WMView';

let {height, width} = Dimensions.get('window');

export default class LoadingMore extends PureComponent {

    // 构造
    constructor(props) {
        super(props);

        this.state = {
            isShow:this.props.isShow,
            hasLoadAll:this.props.hasLoadAll,
            txt:this.props.txt,
        };
    }

    componentWillReceiveProps(nextProps) {
        if(nextProps){
            const { isShow, hasLoadAll, txt } = nextProps;
            this.setState({ isShow, hasLoadAll, txt });
        }
    }

    componentDidMount(){
    }

    componentWillUnmount(){

    }

    componentDidUpdate() {
    }

    /**
     * 切换加载更多状态
     * @param hasLoadAll
     * @param txt
     */
    changeState = (hasLoadAll : Boolean, txt : string)=>{
        this.setState({ hasLoadAll, txt });
    }

    show = ()=>{
        this.setState({isShow:true});
    }

    hidden = ()=>{
        this.setState({isShow:false});
    }

    render() {
        const { isShow, hasLoadAll, txt } = this.state;

        if(!isShow){
            return null;
        }
        const { style, loadAllLineStyle } = this.props;

        let childView = (
            <Text style={styles.txt}>{txt}</Text>
        );
        if(hasLoadAll){ //已经加载全部数据
            childView = (
                <WMView style={styles.loadAllContainer}>
                    <View style={[styles.lineView, loadAllLineStyle]} />
                    <Text style={[styles.txt, {marginLeft: 10, marginRight: 10}]}>没有更多了</Text>
                    <View style={[styles.lineView, loadAllLineStyle]} />
                </WMView>
            );
        }

        return (
            <WMView pointerEvents={'none'} style={[styles.loading, style]}>

                { childView }

            </WMView>
        );
    }

}


const styles = StyleSheet.create({
    loading: {
        width:'100%',
        height:50,
        flexDirection:'row',
        justifyContent: 'center',
        alignItems: 'center',
        backgroundColor:'transparent',
    },
    txt:{
        color:'#CCCCCC',
        fontSize:15,
    },
    loadAllContainer:{
        position:'absolute',
        top:0,
        left:0,
        right:0,
        bottom:0,
        width:'100%',
        height: '100%',
        flexDirection:'row',
        justifyContent: 'center',
        alignItems: 'center',
    },
    lineView:{
        backgroundColor:'#d7d7d7',
        height:0.5,
        flex: 1,
    },
})

==> wm-react-native-components-0.0.66.tgz: package/refreshlistview/LoadingMore.js <==

import React,{Component, PureComponent}  from 'react';
import {
    StyleSheet,
    View,
    Text,
    TouchableWithoutFeedback,
    Dimensions,
    Image,
    Animated,
} from 'react-native';

import WMImage from '../WMImage';
import WMView from '../WMView';

let {height, width} = Dimensions.get('window');

export default class LoadingMore extends PureComponent {

    // 构造
    constructor(props) {
        super(props);

        this.state = {
            isShow:this.props.isShow,
            hasLoadAll:this.props.hasLoadAll,
            txt:this.props.txt,
        };
    }

    componentWillReceiveProps(nextProps) {
        if(nextProps){
            const { isShow, hasLoadAll, txt } = nextProps;
            this.setState({ isShow, hasLoadAll, txt });
        }
    }

    componentDidMount(){
    }

    componentWillUnmount(){

    }

    componentDidUpdate() {
    }

    /**
     * 切换加载更多状态
     * @param hasLoadAll
     * @param txt
     */
    changeState = (hasLoadAll : Boolean, txt : string)=>{
        this.setState({ hasLoadAll, txt });
    }

    show = ()=>{
        this.setState({isShow:true});
    }

    hidden = ()=>{
        this.setState({isShow:false});
    }

    render() {
        const { isShow, hasLoadAll, txt } = this.state;

        if(!isShow){
            return null;
        }
        const { style, loadAllLineStyle } = this.props;

        let childView = (
            <Text style={styles.txt}>{txt}</Text>
        );
        if(hasLoadAll){ //已经加载全部数据 OA V1.0.0 opacity:0 隐藏没有更多UI
            childView = (
                <WMView style={[styles.loadAllContainer, {opacity:0}]}>
                    <View style={[styles.lineView, loadAllLineStyle]} />
                    <Text style={[styles.txt, {marginLeft: 10, marginRight: 10}]}>没有更多了</Text>
                    <View style={[styles.lineView, loadAllLineStyle]} />
                </WMView>
            );
        }

        return (
            <WMView pointerEvents={'none'} style={[styles.loading, style]}>

                { childView }

            </WMView>
        );
    }

}


const styles = StyleSheet.create({
    loading: {
        width:'100%',
        height:50,
        flexDirection:'row',
        justifyContent: 'center',
        alignItems: 'center',
        backgroundColor:'transparent',
    },
    txt:{
        color:'#CCCCCC',
        fontSize:15,
    },
    loadAllContainer:{
        position:'absolute',
        top:0,
        left:0,
        right:0,
        bottom:0,
        width:'100%',
        height: '100%',
        flexDirection:'row',
        justifyContent: 'center',
        alignItems: 'center',
    },
    lineView:{
        backgroundColor:'#d7d7d7',
        height:0.5,
        flex: 1,
    },
})
